@@ -4,38 +4,43 @@
 #' @return Shiny modulde UI for generalized estimating equation(GEE).
 #' @details Shiny modulde UI for generalized estimating equation(GEE).
 #' @examples
-#' library(shiny);library(DT);library(data.table);library(jstable)
+#' library(shiny)
+#' library(DT)
+#' library(data.table)
+#' library(jstable)
 #' ui <- fluidPage(
-#'    sidebarLayout(
-#'    sidebarPanel(
-#'      GEEModuleUI("linear")
-#'    ),
-#'    mainPanel(
-#'      DTOutput("lineartable")
-#'    )
-#'  )
-#')
+#'   sidebarLayout(
+#'     sidebarPanel(
+#'       GEEModuleUI("linear")
+#'     ),
+#'     mainPanel(
+#'       DTOutput("lineartable")
+#'     )
+#'   )
+#' )
 #'
 #' server <- function(input, output, session) {
-#'
 #'   data <- reactive(mtcars)
 #'   data.label <- reactive(jstable::mk.lev(mtcars))
 #'   id.gee <- reactive("mpg")
 #'
-#'   out_linear <- callModule(GEEModuleLinear, "linear", data = data, data_label = data.label,
-#'                            data_varStruct = NULL, id.gee = id.gee)
+#'   out_linear <- callModule(GEEModuleLinear, "linear",
+#'     data = data, data_label = data.label,
+#'     data_varStruct = NULL, id.gee = id.gee
+#'   )
 #'
 #'   output$lineartable <- renderDT({
-#'     hide = which(colnames(out_linear()$table) == "sig")
-#'     datatable(out_linear()$table, rownames=T, extension= "Buttons", caption = out_linear()$caption,
-#'               options = c(opt.tbreg(out_linear()$caption),
-#'                           list(columnDefs = list(list(visible=FALSE, targets =hide))
-#'                           ),
-#'                           list(scrollX = TRUE)
-#'               )
-#'     ) %>% formatStyle("sig", target = 'row',backgroundColor = styleEqual("**", 'yellow'))
+#'     hide <- which(colnames(out_linear()$table) == "sig")
+#'     datatable(out_linear()$table,
+#'       rownames = T, extension = "Buttons", caption = out_linear()$caption,
+#'       options = c(
+#'         opt.tbreg(out_linear()$caption),
+#'         list(columnDefs = list(list(visible = FALSE, targets = hide))),
+#'         list(scrollX = TRUE)
+#'       )
+#'     ) %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
 #'   })
-#'}
+#' }
 #' @rdname GEEModuleUI
 #' @export
 
@@ -47,7 +52,7 @@ GEEModuleUI <- function(id) {
     uiOutput(ns("dep")),
     uiOutput(ns("indep")),
     sliderInput(ns("decimal"), "Digits",
-                min = 1, max = 4, value = 2
+      min = 1, max = 4, value = 2
     ),
     checkboxInput(ns("regressUI_subcheck"), "Sub-group analysis"),
     uiOutput(ns("regressUI_subvar")),
@@ -71,38 +76,43 @@ GEEModuleUI <- function(id) {
 #' @return Shiny modulde server for gaussian generalized estimating equation(GEE).
 #' @details Shiny modulde server for gaussian generalized estimating equation(GEE) using reactive data.
 #' @examples
-#' library(shiny);library(DT);library(data.table);library(jstable)
+#' library(shiny)
+#' library(DT)
+#' library(data.table)
+#' library(jstable)
 #' ui <- fluidPage(
-#'    sidebarLayout(
-#'    sidebarPanel(
-#'      GEEModuleUI("linear")
-#'    ),
-#'    mainPanel(
-#'      DTOutput("lineartable")
-#'    )
-#'  )
-#')
+#'   sidebarLayout(
+#'     sidebarPanel(
+#'       GEEModuleUI("linear")
+#'     ),
+#'     mainPanel(
+#'       DTOutput("lineartable")
+#'     )
+#'   )
+#' )
 #'
 #' server <- function(input, output, session) {
-#'
 #'   data <- reactive(mtcars)
 #'   data.label <- reactive(jstable::mk.lev(mtcars))
 #'   id.gee <- reactive("mpg")
 #'
-#'   out_linear <- callModule(GEEModuleLinear, "linear", data = data, data_label = data.label,
-#'                            data_varStruct = NULL, id.gee = id.gee)
+#'   out_linear <- callModule(GEEModuleLinear, "linear",
+#'     data = data, data_label = data.label,
+#'     data_varStruct = NULL, id.gee = id.gee
+#'   )
 #'
 #'   output$lineartable <- renderDT({
-#'     hide = which(colnames(out_linear()$table) == "sig")
-#'     datatable(out_linear()$table, rownames=T, extension= "Buttons", caption = out_linear()$caption,
-#'               options = c(opt.tbreg(out_linear()$caption),
-#'                           list(columnDefs = list(list(visible=FALSE, targets =hide))
-#'                           ),
-#'                           list(scrollX = TRUE)
-#'               )
-#'     ) %>% formatStyle("sig", target = 'row',backgroundColor = styleEqual("**", 'yellow'))
+#'     hide <- which(colnames(out_linear()$table) == "sig")
+#'     datatable(out_linear()$table,
+#'       rownames = T, extension = "Buttons", caption = out_linear()$caption,
+#'       options = c(
+#'         opt.tbreg(out_linear()$caption),
+#'         list(columnDefs = list(list(visible = FALSE, targets = hide))),
+#'         list(scrollX = TRUE)
+#'       )
+#'     ) %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
 #'   })
-#'}
+#' }
 #' @rdname GEEModuleLinear
 #' @export
 #' @import shiny
@@ -117,30 +127,29 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
 
-  if (is.null(data_varStruct)){
-    data_varStruct = reactive(list(variable = names(data())))
+  if (is.null(data_varStruct)) {
+    data_varStruct <- reactive(list(variable = names(data())))
   }
 
   vlist <- reactive({
-
-    mklist <- function(varlist, vars){
-      lapply(varlist,
-             function(x){
-               inter <- intersect(x, vars)
-               if (length(inter) == 1){
-                 inter <- c(inter, "")
-               }
-               return(inter)
-             })
-
-
+    mklist <- function(varlist, vars) {
+      lapply(
+        varlist,
+        function(x) {
+          inter <- intersect(x, vars)
+          if (length(inter) == 1) {
+            inter <- c(inter, "")
+          }
+          return(inter)
+        }
+      )
     }
 
     id <- id.gee()
 
     factor_vars <- names(data())[data()[, lapply(.SD, class) %in% c("factor", "character")]]
     factor_vars <- setdiff(factor_vars, id)
-    #factor_vars <- names(data())[sapply(names(data()), function(x){class(data()[[x]]) %in% c("factor", "character")})]
+    # factor_vars <- names(data())[sapply(names(data()), function(x){class(data()[[x]]) %in% c("factor", "character")})]
     factor_list <- mklist(data_varStruct(), factor_vars)
 
 
@@ -148,18 +157,20 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
     conti_vars <- setdiff(conti_vars, id)
     conti_list <- mklist(data_varStruct(), conti_vars)
 
-    nclass_factor <- unlist(data()[, lapply(.SD, function(x){length(levels(x))}), .SDcols = factor_vars])
-    #nclass_factor <- sapply(factor_vars, function(x){length(unique(data()[[x]]))})
+    nclass_factor <- unlist(data()[, lapply(.SD, function(x) {
+      length(levels(x))
+    }), .SDcols = factor_vars])
+    # nclass_factor <- sapply(factor_vars, function(x){length(unique(data()[[x]]))})
 
-    group_vars <- factor_vars[nclass_factor >=2 & nclass_factor <= nfactor.limit & nclass_factor < nrow(data())]
+    group_vars <- factor_vars[nclass_factor >= 2 & nclass_factor <= nfactor.limit & nclass_factor < nrow(data())]
     group_list <- mklist(data_varStruct(), group_vars)
 
     except_vars <- factor_vars[nclass_factor > nfactor.limit | nclass_factor == 1 | nclass_factor == nrow(data())]
 
-    return(list(factor_vars = factor_vars, factor_list = factor_list, conti_vars = conti_vars, conti_list = conti_list,
-                group_vars = group_vars, group_list = group_list, except_vars = except_vars)
-    )
-
+    return(list(
+      factor_vars = factor_vars, factor_list = factor_list, conti_vars = conti_vars, conti_list = conti_list,
+      group_vars = group_vars, group_list = group_list, except_vars = except_vars
+    ))
   })
 
 
@@ -167,8 +178,8 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
   output$dep <- renderUI({
     tagList(
       selectInput(session$ns("dep_vars"), "Dependent variable",
-                  choices = vlist()$conti_list, multiple = F,
-                  selected = vlist()$conti_vars[1]
+        choices = vlist()$conti_list, multiple = F,
+        selected = vlist()$conti_vars[1]
       )
     )
   })
@@ -177,8 +188,8 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
   output$indep <- renderUI({
     id <- id.gee()
     req(!is.null(input$dep_vars))
-    vars <- setdiff(setdiff(names(data()), vlist()$except_vars),  c(input$dep_vars, id))
-    #varsIni <- sapply(vars,
+    vars <- setdiff(setdiff(names(data()), vlist()$except_vars), c(input$dep_vars, id))
+    # varsIni <- sapply(vars,
     #                  function(v){
     #                    forms <- as.formula(paste(input$dep_vars, "~", v))
     #                    coef <- summary(geepack::geeglm(forms, data = data()[!is.na(get(v))], family = "gaussian", id = get(id), corstr = "exchangeable"))$coef
@@ -189,8 +200,8 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
 
     tagList(
       selectInput(session$ns("indep_vars"), "Independent variables",
-                  choices = mklist(data_varStruct(), vars), multiple = T,
-                  selected = vars[1]
+        choices = mklist(data_varStruct(), vars), multiple = T,
+        selected = vars[1]
       )
     )
   })
@@ -202,15 +213,15 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
       var_subgroup <- setdiff(names(data()), c(input$dep_vars, input$indep_vars, id.gee()))
       var_subgroup_list <- mklist(data_varStruct(), var_subgroup)
       validate(
-        need(length(var_subgroup) > 0 , "No variables for sub-group analysis")
+        need(length(var_subgroup) > 0, "No variables for sub-group analysis")
       )
 
       tagList(
         selectInput(session$ns("subvar_regress"), "Sub-group variables",
-                    choices = var_subgroup_list, multiple = T,
-                    selected = var_subgroup[1])
+          choices = var_subgroup_list, multiple = T,
+          selected = var_subgroup[1]
+        )
       )
-
     })
 
     output$regressUI_subval <- renderUI({
@@ -219,23 +230,22 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
 
       outUI <- tagList()
 
-      for (v in seq_along(input$subvar_regress)){
-        if (input$subvar_regress[[v]] %in% vlist()$factor_vars){
+      for (v in seq_along(input$subvar_regress)) {
+        if (input$subvar_regress[[v]] %in% vlist()$factor_vars) {
           outUI[[v]] <- selectInput(session$ns(paste0("subval_regress", v)), paste0("Sub-group value: ", input$subvar_regress[[v]]),
-                                    choices = data_label()[variable == input$subvar_regress[[v]], level], multiple = T,
-                                    selected = data_label()[variable == input$subvar_regress[[v]], level][1])
-        } else{
+            choices = data_label()[variable == input$subvar_regress[[v]], level], multiple = T,
+            selected = data_label()[variable == input$subvar_regress[[v]], level][1]
+          )
+        } else {
           val <- stats::quantile(data()[[input$subvar_regress[[v]]]], na.rm = T)
           outUI[[v]] <- sliderInput(session$ns(paste0("subval_regress", v)), paste0("Sub-group range: ", input$subvar_regress[[v]]),
-                                    min = val[1], max = val[5],
-                                    value = c(val[2], val[4]))
+            min = val[1], max = val[5],
+            value = c(val[2], val[4])
+          )
         }
-
       }
       outUI
-
     })
-
   })
 
 
@@ -247,16 +257,18 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
     data.regress <- data()
     label.regress <- data_label()
     idgee_Plz_Noduplicate <- id.gee()
-    if(input$regressUI_subcheck == T){
+    if (input$regressUI_subcheck == T) {
       validate(
-        need(length(input$subvar_regress) > 0 , "No variables for subsetting"),
-        need(all(sapply(1:length(input$subvar_regress), function(x){length(input[[paste0("subval_regress", x)]])})), "No value for subsetting")
+        need(length(input$subvar_regress) > 0, "No variables for subsetting"),
+        need(all(sapply(1:length(input$subvar_regress), function(x) {
+          length(input[[paste0("subval_regress", x)]])
+        })), "No value for subsetting")
       )
 
-      for (v in seq_along(input$subvar_regress)){
-        if (input$subvar_regress[[v]] %in% vlist()$factor_vars){
+      for (v in seq_along(input$subvar_regress)) {
+        if (input$subvar_regress[[v]] %in% vlist()$factor_vars) {
           data.regress <- data.regress[get(input$subvar_regress[[v]]) %in% input[[paste0("subval_regress", v)]]]
-        } else{
+        } else {
           data.regress <- data.regress[get(input$subvar_regress[[v]]) >= input[[paste0("subval_regress", v)]][1] & get(input$subvar_regress[[v]]) <= input[[paste0("subval_regress", v)]][2]]
         }
       }
@@ -269,7 +281,7 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
     y <- input$dep_vars
     xs <- input$indep_vars
     validate(
-      need(!is.null(input$indep_vars) , "Please select at least 1 variable")
+      need(!is.null(input$indep_vars), "Please select at least 1 variable")
     )
     form <- as.formula(paste(y, "~", paste(xs, collapse = " + "), sep = " "))
 
@@ -277,9 +289,9 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
     validate(
       need(nrow(mf) > 0, paste("No complete data due to missingness. Please remove some variables from independent variables"))
     )
-    lgl.1level <- purrr::map_lgl(mf, ~length(unique(.x)) == 1)
+    lgl.1level <- purrr::map_lgl(mf, ~ length(unique(.x)) == 1)
     validate(
-      need(sum(lgl.1level) == 0, paste(paste(names(lgl.1level)[lgl.1level], collapse =" ,"), "has(have) a unique value. Please remove that from independent variables"))
+      need(sum(lgl.1level) == 0, paste(paste(names(lgl.1level)[lgl.1level], collapse = " ,"), "has(have) a unique value. Please remove that from independent variables"))
     )
 
     nomiss <- stats::complete.cases(data.regress[, c(y, xs), with = F])
@@ -290,11 +302,11 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
     out.tb <- rbind(ltb.gee$table, ltb.gee$metric)
     cap.gee <- ltb.gee$caption
 
-    if(input$regressUI_subcheck == T){
-      for (v in seq_along(input$subvar_regress)){
-        if (input$subvar_regress[[v]] %in% vlist()$factor_vars){
+    if (input$regressUI_subcheck == T) {
+      for (v in seq_along(input$subvar_regress)) {
+        if (input$subvar_regress[[v]] %in% vlist()$factor_vars) {
           cap.gee <- paste(cap.gee, ", ", label.regress[variable == input$subvar_regress[[v]], var_label][1], ": ", paste(label.regress[variable == input$subvar_regress[[v]] & level %in% input[[paste0("subval_regress", v)]], val_label], collapse = ", "), sep = "")
-        } else{
+        } else {
           cap.gee <- paste(cap.gee, ", ", label.regress[variable == input$subvar_regress[[v]], var_label][1], ": ", paste(input[[paste0("subval_regress", v)]], collapse = "~"), sep = "")
         }
       }
@@ -305,8 +317,6 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
   })
 
   return(out)
-
-
 }
 
 
@@ -324,39 +334,44 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
 #' @return Shiny modulde server for binomial gaussian generalized estimating equation(GEE).
 #' @details Shiny modulde server for binomial gaussian generalized estimating equation(GEE) using reactive data.
 #' @examples
-#' library(shiny);library(DT);library(data.table);library(jstable)
+#' library(shiny)
+#' library(DT)
+#' library(data.table)
+#' library(jstable)
 #' ui <- fluidPage(
-#'    sidebarLayout(
-#'    sidebarPanel(
-#'      GEEModuleUI("logistic")
-#'    ),
-#'    mainPanel(
-#'      DTOutput("logistictable")
-#'    )
-#'  )
-#')
+#'   sidebarLayout(
+#'     sidebarPanel(
+#'       GEEModuleUI("logistic")
+#'     ),
+#'     mainPanel(
+#'       DTOutput("logistictable")
+#'     )
+#'   )
+#' )
 #'
 #' server <- function(input, output, session) {
-#'
 #'   data <- reactive(mtcars)
 #'   data.label <- reactive(jstable::mk.lev(mtcars))
 #'   id.gee <- reactive("mpg")
 #'
-#'   out_logistic <- callModule(GEEModuleLogistic, "logistic", data = data, data_label = data.label,
-#'                              data_varStruct = NULL, id.gee = id.gee)
+#'   out_logistic <- callModule(GEEModuleLogistic, "logistic",
+#'     data = data, data_label = data.label,
+#'     data_varStruct = NULL, id.gee = id.gee
+#'   )
 #'
 #'   output$logistictable <- renderDT({
-#'     hide = which(colnames(out_logistic()$table) == "sig")
-#'     datatable(out_logistic()$table, rownames=T, extension= "Buttons",
-#'               caption = out_logistic()$caption,
-#'               options = c(opt.tbreg(out_logistic()$caption),
-#'                           list(columnDefs = list(list(visible=FALSE, targets =hide))
-#'                           ),
-#'                           list(scrollX = TRUE)
-#'               )
-#'     ) %>% formatStyle("sig", target = 'row',backgroundColor = styleEqual("**", 'yellow'))
+#'     hide <- which(colnames(out_logistic()$table) == "sig")
+#'     datatable(out_logistic()$table,
+#'       rownames = T, extension = "Buttons",
+#'       caption = out_logistic()$caption,
+#'       options = c(
+#'         opt.tbreg(out_logistic()$caption),
+#'         list(columnDefs = list(list(visible = FALSE, targets = hide))),
+#'         list(scrollX = TRUE)
+#'       )
+#'     ) %>% formatStyle("sig", target = "row", backgroundColor = styleEqual("**", "yellow"))
 #'   })
-#'}
+#' }
 #' @rdname GEEModuleLogistic
 #' @export
 #' @import shiny
@@ -371,60 +386,63 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
 
-  if (is.null(data_varStruct)){
-    data_varStruct = reactive(list(variable = names(data())))
+  if (is.null(data_varStruct)) {
+    data_varStruct <- reactive(list(variable = names(data())))
   }
 
   vlist <- reactive({
-
-    mklist <- function(varlist, vars){
-      lapply(varlist,
-             function(x){
-               inter <- intersect(x, vars)
-               if (length(inter) == 1){
-                 inter <- c(inter, "")
-               }
-               return(inter)
-             })
-
-
+    mklist <- function(varlist, vars) {
+      lapply(
+        varlist,
+        function(x) {
+          inter <- intersect(x, vars)
+          if (length(inter) == 1) {
+            inter <- c(inter, "")
+          }
+          return(inter)
+        }
+      )
     }
 
     id <- id.gee()
 
     factor_vars <- names(data())[data()[, lapply(.SD, class) %in% c("factor", "character")]]
     factor_vars <- setdiff(factor_vars, id)
-    #data[, (factor_vars) := lapply(.SD, as.factor), .SDcols= factor_vars]
+    # data[, (factor_vars) := lapply(.SD, as.factor), .SDcols= factor_vars]
     factor_list <- mklist(data_varStruct(), factor_vars)
 
 
-    nclass_factor <- unlist(data()[, lapply(.SD, function(x){length(levels(x))}), .SDcols = factor_vars])
-    class01_factor <- unlist(data()[, lapply(.SD, function(x){identical(levels(x), c("0", "1"))}), .SDcols = factor_vars])
+    nclass_factor <- unlist(data()[, lapply(.SD, function(x) {
+      length(levels(x))
+    }), .SDcols = factor_vars])
+    class01_factor <- unlist(data()[, lapply(.SD, function(x) {
+      identical(levels(x), c("0", "1"))
+    }), .SDcols = factor_vars])
 
     validate(
-      need(length(class01_factor) >=1, "No categorical variables coded as 0, 1 in data")
+      need(length(class01_factor) >= 1, "No categorical variables coded as 0, 1 in data")
     )
     factor_01vars <- factor_vars[class01_factor]
     factor_01_list <- mklist(data_varStruct(), factor_01vars)
 
 
     except_vars <- factor_vars[nclass_factor > nfactor.limit | nclass_factor == 1 | nclass_factor == nrow(data())]
-    return(list(factor_vars = factor_vars, factor_list = factor_list, nclass_factor = nclass_factor, factor_01vars = factor_01vars,
-                factor_01_list = factor_01_list, except_vars = except_vars)
-    )
-
+    return(list(
+      factor_vars = factor_vars, factor_list = factor_list, nclass_factor = nclass_factor, factor_01vars = factor_01vars,
+      factor_01_list = factor_01_list, except_vars = except_vars
+    ))
   })
 
 
 
   output$dep <- renderUI({
     validate(
-      need(length(vlist()$factor_01vars) >=1 , "No candidate dependent variable coded as 0, 1")
+      need(length(vlist()$factor_01vars) >= 1, "No candidate dependent variable coded as 0, 1")
     )
     tagList(
       selectInput(session$ns("dep_vars"), "Dependent variable",
-                  choices = vlist()$factor_01_list, multiple = F,
-                  selected = vlist()$factor_01vars[1]
+        choices = vlist()$factor_01_list, multiple = F,
+        selected = vlist()$factor_01vars[1]
       )
     )
   })
@@ -433,8 +451,8 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
   output$indep <- renderUI({
     id <- id.gee()
     req(!is.null(input$dep_vars))
-    vars <- setdiff(setdiff(names(data()), vlist()$except_vars),  c(input$dep_vars, id))
-    #varsIni <- sapply(vars,
+    vars <- setdiff(setdiff(names(data()), vlist()$except_vars), c(input$dep_vars, id))
+    # varsIni <- sapply(vars,
     #                  function(v){
     #                    forms <- as.formula(paste(input$dep_vars, "~", v))
     #                    coef <- summary(geepack::geeglm(forms, data = data()[!is.na(get(v))], family = "gaussian", id = get(id), corstr = "exchangeable"))$coef
@@ -445,8 +463,8 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
 
     tagList(
       selectInput(session$ns("indep_vars"), "Independent variables",
-                  choices = mklist(data_varStruct(), vars), multiple = T,
-                  selected = vars[1]
+        choices = mklist(data_varStruct(), vars), multiple = T,
+        selected = vars[1]
       )
     )
   })
@@ -457,13 +475,14 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
       var_subgroup <- setdiff(names(data()), c(input$dep_vars, input$indep_vars, id.gee()))
       var_subgroup_list <- mklist(data_varStruct(), var_subgroup)
       validate(
-        need(length(var_subgroup) > 0 , "No variables for sub-group analysis")
+        need(length(var_subgroup) > 0, "No variables for sub-group analysis")
       )
 
       tagList(
         selectInput(session$ns("subvar_regress"), "Sub-group variables",
-                    choices = var_subgroup_list, multiple = T,
-                    selected = var_subgroup[1])
+          choices = var_subgroup_list, multiple = T,
+          selected = var_subgroup[1]
+        )
       )
     })
 
@@ -473,22 +492,22 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
 
       outUI <- tagList()
 
-      for (v in seq_along(input$subvar_regress)){
-        if (input$subvar_regress[[v]] %in% vlist()$factor_vars){
+      for (v in seq_along(input$subvar_regress)) {
+        if (input$subvar_regress[[v]] %in% vlist()$factor_vars) {
           outUI[[v]] <- selectInput(session$ns(paste0("subval_regress", v)), paste0("Sub-group value: ", input$subvar_regress[[v]]),
-                                    choices = data_label()[variable == input$subvar_regress[[v]], level], multiple = T,
-                                    selected = data_label()[variable == input$subvar_regress[[v]], level][1])
-        } else{
+            choices = data_label()[variable == input$subvar_regress[[v]], level], multiple = T,
+            selected = data_label()[variable == input$subvar_regress[[v]], level][1]
+          )
+        } else {
           val <- stats::quantile(data()[[input$subvar_regress[[v]]]], na.rm = T)
           outUI[[v]] <- sliderInput(session$ns(paste0("subval_regress", v)), paste0("Sub-group range: ", input$subvar_regress[[v]]),
-                                    min = val[1], max = val[5],
-                                    value = c(val[2], val[4]))
+            min = val[1], max = val[5],
+            value = c(val[2], val[4])
+          )
         }
-
       }
       outUI
     })
-
   })
 
 
@@ -502,16 +521,18 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
     data.logistic <- data()
     label.regress <- data_label()
     idgee_Plz_Noduplicate <- id.gee()
-    if(input$regressUI_subcheck == T){
+    if (input$regressUI_subcheck == T) {
       validate(
-        need(length(input$subvar_regress) > 0 , "No variables for subsetting"),
-        need(all(sapply(1:length(input$subvar_regress), function(x){length(input[[paste0("subval_regress", x)]])})), "No value for subsetting")
+        need(length(input$subvar_regress) > 0, "No variables for subsetting"),
+        need(all(sapply(1:length(input$subvar_regress), function(x) {
+          length(input[[paste0("subval_regress", x)]])
+        })), "No value for subsetting")
       )
 
-      for (v in seq_along(input$subvar_regress)){
-        if (input$subvar_regress[[v]] %in% vlist()$factor_vars){
+      for (v in seq_along(input$subvar_regress)) {
+        if (input$subvar_regress[[v]] %in% vlist()$factor_vars) {
           data.logistic <- data.logistic[get(input$subvar_regress[[v]]) %in% input[[paste0("subval_regress", v)]]]
-        } else{
+        } else {
           data.logistic <- data.logistic[get(input$subvar_regress[[v]]) >= input[[paste0("subval_regress", v)]][1] & get(input$subvar_regress[[v]]) <= input[[paste0("subval_regress", v)]][2]]
         }
       }
@@ -526,7 +547,7 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
     data.logistic[[y]] <- as.numeric(as.vector(data.logistic[[y]]))
 
     validate(
-      need(!is.null(input$indep_vars) , "Please select at least 1 variable")
+      need(!is.null(input$indep_vars), "Please select at least 1 variable")
     )
     form <- as.formula(paste(y, "~", paste(xs, collapse = " + "), sep = " "))
 
@@ -534,24 +555,24 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
     validate(
       need(nrow(mf) > 0, paste("No complete data due to missingness. Please remove some variables from independent variables"))
     )
-    lgl.1level <- purrr::map_lgl(mf, ~length(unique(.x)) == 1)
+    lgl.1level <- purrr::map_lgl(mf, ~ length(unique(.x)) == 1)
     validate(
-      need(sum(lgl.1level) == 0, paste(paste(names(lgl.1level)[lgl.1level], collapse =" ,"), "has(have) a unique value. Please remove that from independent variables"))
+      need(sum(lgl.1level) == 0, paste(paste(names(lgl.1level)[lgl.1level], collapse = " ,"), "has(have) a unique value. Please remove that from independent variables"))
     )
 
     nomiss <- stats::complete.cases(data.logistic[, c(y, xs), with = F])
     res.gee <- geepack::geeglm(form, data = data.logistic[nomiss, ], family = "binomial", id = get(idgee_Plz_Noduplicate), corstr = "exchangeable")
     info.gee <- jstable::geeglm.display(res.gee, decimal = input$decimal)
-    info.gee$caption = gsub("idgee_Plz_Noduplicate", idgee_Plz_Noduplicate, info.gee$caption)
+    info.gee$caption <- gsub("idgee_Plz_Noduplicate", idgee_Plz_Noduplicate, info.gee$caption)
     ltb.gee <- jstable::LabeljsGeeglm(info.gee, ref = label.regress)
     out.tb <- rbind(ltb.gee$table, ltb.gee$metric)
     cap.gee <- ltb.gee$caption
 
-    if(input$regressUI_subcheck == T){
-      for (v in seq_along(input$subvar_regress)){
-        if (input$subvar_regress[[v]] %in% vlist()$factor_vars){
+    if (input$regressUI_subcheck == T) {
+      for (v in seq_along(input$subvar_regress)) {
+        if (input$subvar_regress[[v]] %in% vlist()$factor_vars) {
           cap.gee <- paste(cap.gee, ", ", label.regress[variable == input$subvar_regress[[v]], var_label][1], ": ", paste(label.regress[variable == input$subvar_regress[[v]] & level %in% input[[paste0("subval_regress", v)]], val_label], collapse = ", "), sep = "")
-        } else{
+        } else {
           cap.gee <- paste(cap.gee, ", ", label.regress[variable == input$subvar_regress[[v]], var_label][1], ": ", paste(input[[paste0("subval_regress", v)]], collapse = "~"), sep = "")
         }
       }
@@ -562,6 +583,4 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
   })
 
   return(out)
-
-
 }
