@@ -62,7 +62,8 @@ rocUI <- function(id) {
     uiOutput(ns("addmodel")),
     checkboxInput(ns("subcheck"), "Sub-group analysis"),
     uiOutput(ns("subvar")),
-    uiOutput(ns("subval"))
+    uiOutput(ns("subval")),
+    checkboxInput(ns("spetype"), "Show 1-specificity", T)
   )
 }
 
@@ -97,12 +98,12 @@ rocUI <- function(id) {
 
 reclassificationJS <- function(data, cOutcome, predrisk1, predrisk2, cutoff, dec.value = 3, dec.p = 3) {
   c1 <- cut(predrisk1,
-    breaks = cutoff, include.lowest = TRUE,
-    right = FALSE
+            breaks = cutoff, include.lowest = TRUE,
+            right = FALSE
   )
   c2 <- cut(predrisk2,
-    breaks = cutoff, include.lowest = TRUE,
-    right = FALSE
+            breaks = cutoff, include.lowest = TRUE,
+            right = FALSE
   )
   tabReclas <- table(`Initial Model` = c1, `Updated Model` = c2)
   # cat(" _________________________________________\n")
@@ -112,19 +113,19 @@ reclassificationJS <- function(data, cOutcome, predrisk1, predrisk2, cutoff, dec
   # cat("\n Outcome: absent \n  \n")
   TabAbs <- ta[, , 1]
   tab1 <- cbind(TabAbs, ` % reclassified` = round((rowSums(TabAbs) -
-    diag(TabAbs)) / rowSums(TabAbs), 2) * 100)
+                                                     diag(TabAbs)) / rowSums(TabAbs), 2) * 100)
   names(dimnames(tab1)) <- c("Initial Model", "Updated Model")
   # print(tab1)
   # cat("\n \n Outcome: present \n  \n")
   TabPre <- ta[, , 2]
   tab2 <- cbind(TabPre, ` % reclassified` = round((rowSums(TabPre) -
-    diag(TabPre)) / rowSums(TabPre), 2) * 100)
+                                                     diag(TabPre)) / rowSums(TabPre), 2) * 100)
   names(dimnames(tab2)) <- c("Initial Model", "Updated Model")
   # print(tab2)
   # cat("\n \n Combined Data \n  \n")
   Tab <- tabReclas
   tab <- cbind(Tab, ` % reclassified` = round((rowSums(Tab) -
-    diag(Tab)) / rowSums(Tab), 2) * 100)
+                                                 diag(Tab)) / rowSums(Tab), 2) * 100)
   names(dimnames(tab)) <- c("Initial Model", "Updated Model")
   # print(tab)
   # cat(" _________________________________________\n")
@@ -388,8 +389,8 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
 
     tagList(
       selectInput(session$ns("event_roc"), "Event",
-        choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = F,
-        selected = NULL
+                  choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = F,
+                  selected = NULL
       )
     )
   })
@@ -439,8 +440,8 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
 
   output$indep <- renderUI({
     selectInput(session$ns(paste0("indep_roc", 1)), paste0("Independent variables for Model ", 1),
-      choices = mklist(data_varStruct(), indeproc()), multiple = T,
-      selected = unlist(mklist(data_varStruct(), indeproc()))[1]
+                choices = mklist(data_varStruct(), indeproc()), multiple = T,
+                selected = unlist(mklist(data_varStruct(), indeproc()))[1]
     )
   })
 
@@ -449,8 +450,8 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
       selector = paste0("div:has(> #", session$ns("add"), ")"),
       where = "beforeBegin",
       ui = selectInput(session$ns(paste0("indep_roc", nmodel() + 1)), paste0("Independent variables for Model ", nmodel() + 1),
-        choices = mklist(data_varStruct(), indeproc()), multiple = T,
-        selected = unlist(mklist(data_varStruct(), indeproc()))[1:min(length(indeproc()), nmodel() + 1)]
+                       choices = mklist(data_varStruct(), indeproc()), multiple = T,
+                       selected = unlist(mklist(data_varStruct(), indeproc()))[1:min(length(indeproc()), nmodel() + 1)]
       )
     )
     nmodel(nmodel() + 1)
@@ -493,8 +494,8 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
 
       tagList(
         selectInput(session$ns("subvar_roc"), "Sub-group variables",
-          choices = var_subgroup_list, multiple = T,
-          selected = var_subgroup[1]
+                    choices = var_subgroup_list, multiple = T,
+                    selected = var_subgroup[1]
         )
       )
     })
@@ -510,14 +511,14 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
     for (v in seq_along(input$subvar_roc)) {
       if (input$subvar_roc[[v]] %in% vlist()$factor_vars) {
         outUI[[v]] <- selectInput(session$ns(paste0("subval_roc", v)), paste0("Sub-group value: ", input$subvar_roc[[v]]),
-          choices = data_label()[variable == input$subvar_roc[[v]], level], multiple = T,
-          selected = data_label()[variable == input$subvar_roc[[v]], level][1]
+                                  choices = data_label()[variable == input$subvar_roc[[v]], level], multiple = T,
+                                  selected = data_label()[variable == input$subvar_roc[[v]], level][1]
         )
       } else {
         val <- stats::quantile(data()[[input$subvar_roc[[v]]]], na.rm = T)
         outUI[[v]] <- sliderInput(session$ns(paste0("subval_roc", v)), paste0("Sub-group range: ", input$subvar_roc[[v]]),
-          min = val[1], max = val[5],
-          value = c(val[2], val[4])
+                                  min = val[1], max = val[5],
+                                  value = c(val[2], val[4])
         )
       }
     }
@@ -572,8 +573,13 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
       if (is.null(id.cluster)) {
         res.roc <- lapply(indeps(), function(x) {
           forms <- paste0(input$event_roc, "~", paste(x, collapse = "+"))
-          mm <- glm(as.formula(forms), data = data.roc, family = binomial)
-          pROC::roc(mm$y, predict(mm, type = "response"))
+          mm <- glm(as.formula(forms), data = data.roc, family = binomial, x = T)
+          if (length(x) > 1){
+            return(pROC::roc(mm$y, predict(mm, type = "response")))
+          } else{
+            return(pROC::roc(mm$y, mm$x[, 2]))
+          }
+
         })
 
         if (nmodel() == 1 & length(indeps()) == 1) {
@@ -622,8 +628,12 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
       }
       res.roc <- lapply(indeps(), function(x) {
         forms <- paste0(input$event_roc, "~", paste(x, collapse = "+"))
-        mm <- survey::svyglm(as.formula(forms), design = data.design, family = quasibinomial())
-        pROC::roc(mm$y, as.matrix(predict(mm, type = "response")))
+        mm <- survey::svyglm(as.formula(forms), design = data.design, family = quasibinomial(), x= T)
+        if (length(x) > 1){
+          return(pROC::roc(mm$y, predict(mm, type = "response")))
+        } else{
+          return(pROC::roc(mm$y, mm$x[, 2]))
+        }
       })
 
       if (nmodel() == 1 & length(indeps()) == 1) {
@@ -636,8 +646,7 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
     }
 
 
-    p <- pROC::ggroc(res.roc) + see::theme_modern() + geom_abline(slope = 1, intercept = 1, lty = 2) +
-      xlab("Specificity") + ylab("Sensitivity") + scale_color_discrete("Model", labels = paste("Model", 1:nmodel()))
+    p <- pROC::ggroc(res.roc, legacy.axes = input$spetype) + see::theme_modern() + geom_abline(slope = 1, intercept = as.integer(!input$spetype), lty = 2)  + scale_color_discrete("Model", labels = paste("Model", 1:nmodel()))
 
     return(list(plot = p, cut = res.cut, tb = res.tb))
   })
@@ -651,20 +660,20 @@ rocModule <- function(input, output, session, data, data_label, data_varStruct =
       column(
         4,
         selectizeInput(session$ns("file_ext"), "File extension (dpi = 300)",
-          choices = c("jpg", "pdf", "tiff", "svg", "pptx"), multiple = F,
-          selected = "pptx"
+                       choices = c("jpg", "pdf", "tiff", "svg", "pptx"), multiple = F,
+                       selected = "pptx"
         )
       ),
       column(
         4,
         sliderInput(session$ns("fig_width"), "Width (in):",
-          min = 5, max = 15, value = 8
+                    min = 5, max = 15, value = 8
         )
       ),
       column(
         4,
         sliderInput(session$ns("fig_height"), "Height (in):",
-          min = 5, max = 15, value = 6
+                    min = 5, max = 15, value = 6
         )
       )
     )
@@ -864,8 +873,8 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
 
     tagList(
       selectInput(session$ns("event_roc"), "Event",
-        choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = F,
-        selected = NULL
+                  choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = F,
+                  selected = NULL
       )
     )
   })
@@ -911,8 +920,8 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
     lapply(1:nmodel(), {
       function(x) {
         selectInput(session$ns(paste0("indep_roc", x)), paste0("Independent variables for Model ", x),
-          choices = mklist(data_varStruct(), indeproc()), multiple = T,
-          selected = unlist(mklist(data_varStruct(), indeproc()))[x]
+                    choices = mklist(data_varStruct(), indeproc()), multiple = T,
+                    selected = unlist(mklist(data_varStruct(), indeproc()))[x]
         )
       }
     })
@@ -950,8 +959,8 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
 
       tagList(
         selectInput(session$ns("subvar_roc"), "Sub-group variables",
-          choices = var_subgroup_list, multiple = T,
-          selected = var_subgroup[1]
+                    choices = var_subgroup_list, multiple = T,
+                    selected = var_subgroup[1]
         )
       )
     })
@@ -967,14 +976,14 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
     for (v in seq_along(input$subvar_roc)) {
       if (input$subvar_roc[[v]] %in% vlist()$factor_vars) {
         outUI[[v]] <- selectInput(session$ns(paste0("subval_roc", v)), paste0("Sub-group value: ", input$subvar_roc[[v]]),
-          choices = data_label()[variable == input$subvar_roc[[v]], level], multiple = T,
-          selected = data_label()[variable == input$subvar_roc[[v]], level][1]
+                                  choices = data_label()[variable == input$subvar_roc[[v]], level], multiple = T,
+                                  selected = data_label()[variable == input$subvar_roc[[v]], level][1]
         )
       } else {
         val <- stats::quantile(data()[[input$subvar_roc[[v]]]], na.rm = T)
         outUI[[v]] <- sliderInput(session$ns(paste0("subval_roc", v)), paste0("Sub-group range: ", input$subvar_roc[[v]]),
-          min = val[1], max = val[5],
-          value = c(val[2], val[4])
+                                  min = val[1], max = val[5],
+                                  value = c(val[2], val[4])
         )
       }
     }
@@ -1029,8 +1038,12 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
       if (is.null(id.cluster)) {
         res.roc <- lapply(indeps(), function(x) {
           forms <- paste0(input$event_roc, "~", paste(x, collapse = "+"))
-          mm <- glm(as.formula(forms), data = data.roc, family = binomial)
-          pROC::roc(mm$y, predict(mm, type = "response"))
+          mm <- glm(as.formula(forms), data = data.roc, family = binomial, x = T)
+          if (length(x) > 1){
+            return(pROC::roc(mm$y, predict(mm, type = "response")))
+          } else{
+            return(pROC::roc(mm$y, mm$x[, 2]))
+          }
         })
 
         if (nmodel() == 1 & length(indeps()) == 1) {
@@ -1079,8 +1092,12 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
       }
       res.roc <- lapply(indeps(), function(x) {
         forms <- paste0(input$event_roc, "~", paste(x, collapse = "+"))
-        mm <- survey::svyglm(as.formula(forms), design = data.design, family = quasibinomial())
-        pROC::roc(mm$y, as.matrix(predict(mm, type = "response")))
+        mm <- survey::svyglm(as.formula(forms), design = data.design, family = quasibinomial(), x= T)
+        if (length(x) > 1){
+          return(pROC::roc(mm$y, predict(mm, type = "response")))
+        } else{
+          return(pROC::roc(mm$y, mm$x[, 2]))
+        }
       })
 
       if (nmodel() == 1 & length(indeps()) == 1) {
@@ -1093,8 +1110,7 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
     }
 
 
-    p <- pROC::ggroc(res.roc) + see::theme_modern() + geom_abline(slope = 1, intercept = 1, lty = 2) +
-      xlab("Specificity") + ylab("Sensitivity") + scale_color_discrete("Model", labels = paste("Model", 1:nmodel()))
+    p <- pROC::ggroc(res.roc, legacy.axes = input$spetype) + see::theme_modern() + geom_abline(slope = 1, intercept = as.integer(!input$spetype), lty = 2)  + scale_color_discrete("Model", labels = paste("Model", 1:nmodel()))
 
     return(list(plot = p, cut = res.cut, tb = res.tb))
   })
@@ -1108,20 +1124,20 @@ rocModule2 <- function(input, output, session, data, data_label, data_varStruct
       column(
         4,
         selectizeInput(session$ns("file_ext"), "File extension (dpi = 300)",
-          choices = c("jpg", "pdf", "tiff", "svg", "pptx"), multiple = F,
-          selected = "pptx"
+                       choices = c("jpg", "pdf", "tiff", "svg", "pptx"), multiple = F,
+                       selected = "pptx"
         )
       ),
       column(
         4,
         sliderInput(session$ns("fig_width"), "Width (in):",
-          min = 5, max = 15, value = 8
+                    min = 5, max = 15, value = 8
         )
       ),
       column(
         4,
         sliderInput(session$ns("fig_height"), "Height (in):",
-          min = 5, max = 15, value = 6
+                    min = 5, max = 15, value = 6
         )
       )
     )
